
/**********************************************************************************
 Persistence of Vision Ray Tracer Scene Description File
 File name   : Eval_pigmentTest.pov
 Version     : 3.6
 Description : Use of eval_pigment() to place objects in combination with trace()
               on a height_field or an isosurface
               with thanks to Norbert Kern's "Warm-up" (1st place IRTC May-June 2001)
               
 Date        : March 2005
 Author      : Thomas A. M. de Groot
 E-mail      : t.degroot@inter.nl.net
 
 Copyright (C) 2005. All rights reserved.
**********************************************************************************/

#version 3.6;

#include "colors.inc"
#include "functions.inc"
#include "rand.inc"

global_settings {
  assumed_gamma 1.0
}

default {
  texture {
    pigment { rgb <1,0,0> }
  }
}

#declare Grey = texture{pigment{Gray50}}
// ----------------------------------------

camera {
  location  <0.0, 1, -3.0>
  direction 1.5*z
  right     x*image_width/image_height
  look_at   <0.0, 0.0,  0.0>
}

sky_sphere {
  pigment {
    gradient y
    color_map {
      [0.0 rgb <0.6,0.7,1.0>]
      [0.7 rgb <0.0,0.1,0.8>]
    }
  }
}

light_source {
  <0, 0, 0>            // light's position (translated below)
  color rgb <1, 1, 1>  // light's color
  translate <-30, 30, -30>
}

// ----------------------------------------

plane {
  y, -1
  pigment { color rgb <0.7,0.5,0.3> }
}

#declare SpottedMap = 
pigment {
  image_map {
    png "Spotted3x_tile.png"
  } 
  rotate x*90 
  translate <-0.5,-0.5,-0.5> 
  scale <2,0.1,2>
} 

#declare HF =
height_field {
  png "Spotted3x_tile.png" 
  //smooth         
  translate <-0.5,-0.5,-0.5>
  scale <2,0.1,2>
  texture {
    pigment {
      SpottedMap
    }
  }
  //normal {granite}
  finish {
    phong .5 
    ambient .05 
    diffuse .7
  }
}

object {HF}

#declare Rod1 = cylinder { <0, 0, 0>, <0, 0.2, 0>, 0.005 texture {pigment {Red}}}
#declare Rod2 = cylinder { <0, 0, 0>, <0, 0.2, 0>, 0.005 texture {pigment {Green}}}
#declare Rod3 = cylinder { <0, 0, 0>, <0, 0.2, 0>, 0.005 texture {pigment {Blue}}}

#include "Eval_pigment_mcr.inc"

// -------- Placing objects -------------
#declare Seed=seed(2);

#declare Spacing = 0.05;
#declare PosX = -2;

#while (PosX < 2)
  #declare PosZ = -2;
  #while (PosZ < 2)
    // trace function
    #declare Norm = <0, 0, 0>;
    #declare Start = <PosX+(rand(Seed)-0.5)*Spacing, 2, PosZ+(rand(Seed)-0.5)*Spacing>;
    #declare Pos = trace (
                  HF,     	 // surface to test
                  Start,     // starting point
                  -y,        // direction
                  Norm );    // normal

    #if (Norm.x != 0 | Norm.y != 0 | Norm.z != 0)   // if intersection is found, normal differs from 0
    
      #if ((vdot(Norm, y)>0.3) & (Pos.y > -1.0))  	// criteria for placing objects: not too steep and not too high
        
        EvalPig3x(SpottedMap,Pos,Rod1,Rod2,Rod3,1,2,0,0,Seed)  // selection of objects according to eval_pigment of the image_map
        
      #end //end of if vdot() & Pos.y
      
    #end //end of if Norm

    #declare PosZ=PosZ+Spacing;
  #end //end of while Z

  #declare PosX=PosX+Spacing;
#end //end of while X

