
/**********************************************************************************
 Persistence of Vision Ray Tracer Scene Description File
 File name   : Eval_pigment_mcr.inc
 Version     : 3.6 / MegaPOV 1.0
 Description : A collection of macros using the eval_pigment() function, for placing
               objects on a surface according to the luminosity of the provided
               image_map.
               
               For large amounts of objects, it is better to copy the macros Lum(col)
               and one of the EvalPig, to the scene file for increased parsing speed.
               
               The following image_maps are available:
               - Spotted2x.png
               - Spotted2x_tile.png (tileable map)
               - Spotted3x.png
               - Spotted3x_tile.png (tileable map)
               
 Date        : April 2005
 Author      : Thomas A. M. de Groot
 E-mail      : t.degroot@inter.nl.net
 
 Copyright (C) 2005. All rights reserved.
**********************************************************************************/

//Little macro from "warm-up" by Norbert Kern (1st place, IRTC May-June 2001)
#macro Lum(col) col.x*.3333+col.y*.3333+col.z*.3333 #end

// Macro using the 2 colours image_map Spotted2x.png or Spotted2x_tile.png :
#macro EvalPig2x(Map,Pos,Object1, Object2,MinScale,MaxScale,MinRot,MaxRot,Seed)
  #if (Lum(eval_pigment(Map,<Pos.x,0,Pos.z>)) < 0.5)
    object {
      Object1
      scale RRand(MinScale, MaxScale, Seed)
      rotate RRand(MinRot, MaxRot, Seed)*y
      translate Pos
    }
  #else
    object {
      Object2
      scale RRand(MinScale, MaxScale, Seed)
      rotate RRand(MinRot, MaxRot, Seed)*y
      translate Pos
    }
  #end //end of eval_pigment
#end // end of macro


// Macro using the 3 colours image_map Spotted3x.png or Spotted3x_tile.png :
#macro EvalPig3x(Map,Pos,Object1,Object2,Object3,MinScale,MaxScale,MinRot,MaxRot,Seed)
  #if (Lum(eval_pigment(Map,<Pos.x,0,Pos.z>)) < 0.21)
    object {
      Object1
      scale RRand(MinScale, MaxScale, Seed)
      rotate RRand(MinRot, MaxRot, Seed)*y
      translate Pos
    }
  #end
  #if (Lum(eval_pigment(Map,<Pos.x,0,Pos.z>)) >= 0.21 & Lum(eval_pigment(Map,<Pos.x,0,Pos.z>)) < 0.99)
    object {
      Object2
      scale RRand(MinScale, MaxScale, Seed)
      rotate RRand(MinRot, MaxRot, Seed)*y
      translate Pos
    }
  #end
  #if (Lum(eval_pigment(Map,<Pos.x,0,Pos.z>)) >= 0.99)
    object {
      Object3
      scale RRand(MinScale, MaxScale, Seed)
      rotate RRand(MinRot, MaxRot, Seed)*y
      translate Pos
    }
  #end
#end // end of macro